@@ -109,7 +109,7 @@ ChatWindow::ChatWindow(Account* account, ChatSession* s)
 		//editorsWidget->setStyleSheet("QTabWidget::pane { border: 0px; } QTabWidget::tab-bar { left: 1px; } QTabBar::tab { padding: 0px 32px 0px 32px; font: bold 9px; }");
 		editorsWidget->setTabPosition(QTabWidget::East);
 		editorsWidget->setTabShape(QTabWidget::Triangular);
-		editorsWidget->setMinimumHeight(80);
+		editorsWidget->setMinimumHeight(120);
 
 		messageEditor = new MessageEditor(m_account, session->contact());
 		connect(messageEditor, SIGNAL(sendPressed()), this, SLOT(sendMessage()));
@@ -130,6 +130,7 @@ ChatWindow::ChatWindow(Account* account, ChatSession* s)
 		{
 			smsEditor = new SmsEditor(m_account, session->contact());
 			connect(smsEditor, SIGNAL(sendPressed()), this, SLOT(sendSms()));
+			connect(editorsWidget, SIGNAL(currentChanged(int)), this, SLOT(sendButtonEnabledProcess()));
 
 			editorsWidget->addTab(smsEditor, tr("SMS"));
 
@@ -168,12 +169,13 @@ ChatWindow::ChatWindow(Account* account, ChatSession* s)
 
 		smsEditor = new SmsEditor(s->account(), s->contact());
 		connect(smsEditor, SIGNAL(sendPressed()), this, SLOT(sendSms()));
+
 		splitter->addWidget(smsEditor);
 	}
 
 	checkContactStatus(session->contact()->status());
 
-	splitter->setStretchFactor(0, 10);
+	splitter->setStretchFactor(0, 7);
 	splitter->setContentsMargins(0,0,0,0);
 	splitter->setStretchFactor(1, 3);
 
@@ -347,7 +349,7 @@ void ChatWindow::appendMessageToView(const Message* msg, bool newIncoming)
 void ChatWindow::contactTyping()
 {
 	qDebug() << "ChatWindow::contactTyping()";
-	statusBar->showMessage(tr("Contact is typing"), 7000);
+
 
 	timer->start(7000);
 	setContactStatusIcon("typing");
@@ -499,7 +501,7 @@ void ChatWindow::slotTimeout()
 void ChatWindow::clearStatus()
 {
 	qDebug() << "ChatWindow::clearStatus()";
-	statusBar->clearMessage();
+
 	if (isNewMessage)
 		setContactStatusIcon("message");
 	else
@@ -714,8 +716,15 @@ void ChatWindow::contactUpdated()
 void ChatWindow::sendButtonEnabledProcess()
 {
 	qDebug() << "sendButtonEnabledProcess()";
-	PlainTextExporter textExporter(messageEditor->document());
-	QString messageText = textExporter.toText();
+	QString messageText;
+	if (messageEditor && messageEditor->isVisible())
+	{
+	    PlainTextExporter textExporter(messageEditor->document());
+	    messageText = textExporter.toText();
+	}
+	else if (smsEditor && smsEditor->isVisible())
+		messageText="hack";
+
 
 	if (!m_account->onlineStatus().connected() || (session->contact()->isConference() && session->contact()->isTemporary()) || messageText.isEmpty())
 		sendButton->setEnabled(false);
